Wrap list of ggkm plots into a single patchwork
wrap_ggkm.RdKaplan-Meier plots generated for multiple survival outcomes can be wrapped into a single figure.
Arguments
- x
list of
ggkm()figures- ncol
number of columns to wrap plots into. Default is 1.
- nrow
number of rows to wrap plots into.
- ...
additional annotation parameters passed to
patchwork::plot_annotation()